# untrack-gitignored-files
A command-line tool to list and untrack gitignored files.

## Installation

```bash
pip install untrack-gitignored-files
```

## Usage

```bash
options:
  -h, --help  show this help message and exit
  --doit      Actually untrack gitignored files.
  --commit    Create a commit after untracking files.
```
